@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 """
-@author:XuMing（xuming624@qq.com)
+@author:XuMing(xuming624@qq.com)
 @description: 
 """
 
 import os
 import sys
 import time
-from codecs import open
 
 import numpy as np
 import torch
@@ -15,18 +14,17 @@ from torch import optim
 
 sys.path.append('../..')
 from pycorrector.deep_context import config
-from pycorrector.deep_context.data_util import write_embedding, write_config
+from pycorrector.deep_context.data_reader import write_config
 from pycorrector.deep_context.model import Context2vec
-from pycorrector.deep_context.reader import Dataset
+from pycorrector.deep_context.dataset import Dataset
 
 
-def train(train_path: str,
-          emb_path: str,
-          model_path: str,
+def train(train_path,
+          model_path,
+          vocab_path,
           use_mlp=True,
           batch_size=64,
           epochs=3,
-          maxlen=64,
           word_embed_size=200,
           hidden_size=200,
           learning_rate=0.0001,
@@ -38,42 +36,23 @@ def train(train_path: str,
     device = torch.device('cpu')
     if use_cuda:
         device = torch.device('cuda:{}'.format(gpu_id))
+        print("use gpu, gpu_id={}".format(gpu_id))
 
     if not os.path.isfile(train_path):
         raise FileNotFoundError
 
-    # make output dir
-    output_dir = os.path.dirname(emb_path)
-    if output_dir and not os.path.exists(output_dir):
-        os.makedirs(output_dir)
-
     print('Loading input file')
-    counter = 0
-    with open(train_path, mode='r', encoding='utf-8') as f:
-        for line in f:
-            sentence = line.strip().lower().split()
-            if 0 < len(sentence):
-                counter += 1
-
-    sentences = np.empty(counter, dtype=object)
-    counter = 0
-    with open(train_path, 'r', encoding='utf-8') as f:
-        for line in f:
-            sentence = line.strip().lower().split()
-            if len(sentence) > 0:
-                sentences[counter] = np.array(sentence[:maxlen])
-                counter += 1
-
-    print('Creating dataset, data size:', counter)
-    dataset = Dataset(sentences, batch_size, min_freq, device)
-    counter = np.array([dataset.vocab.freqs[word] if word in dataset.vocab.freqs else 0
-                        for word in dataset.vocab.itos])
-    model = Context2vec(vocab_size=len(dataset.vocab),
+    dataset = Dataset(train_path,
+                      batch_size,
+                      min_freq,
+                      device,
+                      vocab_path)
+    counter = np.array([dataset.word_freqs[word] for word in dataset.vocab_2_ids])
+    model = Context2vec(vocab_size=len(dataset.vocab_2_ids),
                         counter=counter,
                         word_embed_size=word_embed_size,
                         hidden_size=hidden_size,
                         n_layers=n_layers,
-                        bidirectional=True,
                         use_mlp=use_mlp,
                         dropout=dropout,
                         pad_index=dataset.pad_index,
@@ -88,17 +67,16 @@ def train(train_path: str,
     # save model config
     output_config_file = model_path + '.config.json'
     write_config(output_config_file,
-                 vocab_size=len(dataset.vocab),
+                 vocab_size=len(dataset.vocab_2_ids),
                  word_embed_size=word_embed_size,
                  hidden_size=hidden_size,
                  n_layers=n_layers,
-                 bidirectional=True,
                  use_mlp=use_mlp,
                  dropout=dropout,
                  pad_index=dataset.pad_index,
                  pad_token=dataset.pad_token,
                  unk_token=dataset.unk_token,
-                 bos_token=dataset.bos_token,
+                 sos_token=dataset.sos_token,
                  eos_token=dataset.eos_token,
                  learning_rate=learning_rate
                  )
@@ -115,33 +93,34 @@ def train(train_path: str,
         last_accum_loss = 0.0
         last_word_count = 0
         cur_loss = 0
-        for iterator in dataset.get_batch_iter(batch_size):
-            for batch in iterator:
-                sentence = getattr(batch, 'sentence')
-                target = sentence[:, 1:-1]
-                if target.size(0) == 0:
-                    continue
-                optimizer.zero_grad()
-                loss = model(sentence, target)
-                loss.backward()
-                optimizer.step()
-                total_loss += loss.data.mean()
+        for it, (mb_x, mb_x_len) in enumerate(dataset.train_data):
+            sentence = torch.from_numpy(mb_x).to(device).long()
+            sentence_len = torch.from_numpy(mb_x_len).to(device).long()
 
-                minibatch_size, sentence_length = target.size()
-                word_count += minibatch_size * sentence_length
-                accum_mean_loss = float(total_loss) / word_count if total_loss > 0.0 else 0.0
-                cur_mean_loss = (float(total_loss) - last_accum_loss) / (word_count - last_word_count)
-                cur_loss = cur_mean_loss
-                if word_count >= next_count:
-                    now = time.time()
-                    duration = now - cur_at
-                    throuput = float((word_count - last_word_count)) / (now - cur_at)
-                    print('{} words, {:.2f} sec, {:.2f} words/sec, {:.4f} accum_loss/word, {:.4f} cur_loss/word'
-                          .format(word_count, duration, throuput, accum_mean_loss, cur_mean_loss))
-                    next_count += interval
-                    cur_at = now
-                    last_accum_loss = float(total_loss)
-                    last_word_count = word_count
+            target = sentence[:, 1:-1]
+            if target.size(0) == 0:
+                continue
+            optimizer.zero_grad()
+            loss = model(sentence, target)
+            loss.backward()
+            optimizer.step()
+            total_loss += loss.data.mean()
+
+            minibatch_size, sentence_length = target.size()
+            word_count += minibatch_size * sentence_length
+            accum_mean_loss = float(total_loss) / word_count if total_loss > 0.0 else 0.0
+            cur_mean_loss = (float(total_loss) - last_accum_loss) / (word_count - last_word_count)
+            cur_loss = cur_mean_loss
+            if word_count >= next_count:
+                now = time.time()
+                duration = now - cur_at
+                throuput = float((word_count - last_word_count)) / (now - cur_at)
+                print('{} words, {:.2f} sec, {:.2f} words/sec, {:.4f} accum_loss/word, {:.4f} cur_loss/word'
+                      .format(word_count, duration, throuput, accum_mean_loss, cur_mean_loss))
+                next_count += interval
+                cur_at = now
+                last_accum_loss = float(total_loss)
+                last_word_count = word_count
 
         # find best model
         is_best = cur_loss < best_loss
@@ -149,24 +128,22 @@ def train(train_path: str,
         print('epoch:[{}/{}], total_loss:[{}], best_cur_loss:[{}]'
               .format(epoch + 1, epochs, total_loss.item(), best_loss))
         if is_best:
-            save_checkpoint(model, optimizer, model_path, dataset, use_cuda, emb_path)
+            save_checkpoint(model, optimizer, model_path)
             print('epoch:{}, save new bert model:{}'.format(epoch + 1, model_path))
 
 
-def save_checkpoint(model, optimizer, model_path, dataset, use_cuda, emb_path):
-    write_embedding(dataset.vocab.itos, model.criterion.W, use_cuda, emb_path)
+def save_checkpoint(model, optimizer, model_path):
     torch.save(model.state_dict(), model_path)
     torch.save(optimizer.state_dict(), model_path + '_optim')
 
 
 if __name__ == "__main__":
     train(config.train_path,
-          config.emb_path,
           config.model_path,
+          config.vocab_path,
           config.use_mlp,
           config.batch_size,
           config.epochs,
-          config.maxlen,
           config.word_embed_size,
           config.hidden_size,
           config.learning_rate,
